@@ -37,7 +37,7 @@ def _get_kwargs(
     }
 
 
-def _parse_response(*, response: httpx.Response) -> Optional[Union[List[ChunkEntities], None, None]]:
+def _parse_response(*, response: httpx.Response) -> Optional[Union[List[ChunkEntities], None]]:
     if response.status_code == 200:
         response_200 = []
         _response_200 = response.json()
@@ -58,7 +58,7 @@ def _parse_response(*, response: httpx.Response) -> Optional[Union[List[ChunkEnt
     return None
 
 
-def _build_response(*, response: httpx.Response) -> Response[Union[List[ChunkEntities], None, None]]:
+def _build_response(*, response: httpx.Response) -> Response[Union[List[ChunkEntities], None]]:
     return Response(
         status_code=response.status_code,
         content=response.content,
@@ -73,7 +73,7 @@ def sync_detailed(
     chunks_in: List[str],
     limit: Union[Unset, int] = 100,
     offset: Union[Unset, int] = 0,
-) -> Response[Union[List[ChunkEntities], None, None]]:
+) -> Response[Union[List[ChunkEntities], None]]:
     kwargs = _get_kwargs(
         client=client,
         chunks_in=chunks_in,
@@ -94,7 +94,7 @@ def sync(
     chunks_in: List[str],
     limit: Union[Unset, int] = 100,
     offset: Union[Unset, int] = 0,
-) -> Optional[Union[List[ChunkEntities], None, None]]:
+) -> Optional[Union[List[ChunkEntities], None]]:
     """ Get the chunks entities from a given list of chunk ids. """
 
     return sync_detailed(
@@ -111,7 +111,7 @@ async def asyncio_detailed(
     chunks_in: List[str],
     limit: Union[Unset, int] = 100,
     offset: Union[Unset, int] = 0,
-) -> Response[Union[List[ChunkEntities], None, None]]:
+) -> Response[Union[List[ChunkEntities], None]]:
     kwargs = _get_kwargs(
         client=client,
         chunks_in=chunks_in,
@@ -131,7 +131,7 @@ async def asyncio(
     chunks_in: List[str],
     limit: Union[Unset, int] = 100,
     offset: Union[Unset, int] = 0,
-) -> Optional[Union[List[ChunkEntities], None, None]]:
+) -> Optional[Union[List[ChunkEntities], None]]:
     """ Get the chunks entities from a given list of chunk ids. """
 
     return (
