@@ -26,9 +26,7 @@ def _get_kwargs(
     }
 
 
-def _parse_response(
-    *, response: httpx.Response
-) -> Optional[Union[ExtractWithConfigOut, None, None, None, HTTPValidationError]]:
+def _parse_response(*, response: httpx.Response) -> Optional[Union[ExtractWithConfigOut, HTTPValidationError, None]]:
     if response.status_code == 200:
         response_200 = ExtractWithConfigOut.from_dict(response.json())
 
@@ -52,9 +50,7 @@ def _parse_response(
     return None
 
 
-def _build_response(
-    *, response: httpx.Response
-) -> Response[Union[ExtractWithConfigOut, None, None, None, HTTPValidationError]]:
+def _build_response(*, response: httpx.Response) -> Response[Union[ExtractWithConfigOut, HTTPValidationError, None]]:
     return Response(
         status_code=response.status_code,
         content=response.content,
@@ -67,7 +63,7 @@ def sync_detailed(
     *,
     client: AuthenticatedClient,
     task_id: int,
-) -> Response[Union[ExtractWithConfigOut, None, None, None, HTTPValidationError]]:
+) -> Response[Union[ExtractWithConfigOut, HTTPValidationError, None]]:
     kwargs = _get_kwargs(
         client=client,
         task_id=task_id,
@@ -84,7 +80,7 @@ def sync(
     *,
     client: AuthenticatedClient,
     task_id: int,
-) -> Optional[Union[ExtractWithConfigOut, None, None, None, HTTPValidationError]]:
+) -> Optional[Union[ExtractWithConfigOut, HTTPValidationError, None]]:
     """Get a single extract task.
 
     Only orgadmins are allowed to access extract tasks.
@@ -101,7 +97,7 @@ async def asyncio_detailed(
     *,
     client: AuthenticatedClient,
     task_id: int,
-) -> Response[Union[ExtractWithConfigOut, None, None, None, HTTPValidationError]]:
+) -> Response[Union[ExtractWithConfigOut, HTTPValidationError, None]]:
     kwargs = _get_kwargs(
         client=client,
         task_id=task_id,
@@ -117,7 +113,7 @@ async def asyncio(
     *,
     client: AuthenticatedClient,
     task_id: int,
-) -> Optional[Union[ExtractWithConfigOut, None, None, None, HTTPValidationError]]:
+) -> Optional[Union[ExtractWithConfigOut, HTTPValidationError, None]]:
     """Get a single extract task.
 
     Only orgadmins are allowed to access extract tasks.
