@@ -38,7 +38,7 @@ def _get_kwargs(
 
 def _parse_response(
     *, response: httpx.Response
-) -> Optional[Union[List[ExtractWithConfigOut], None, None, HTTPValidationError]]:
+) -> Optional[Union[HTTPValidationError, List[ExtractWithConfigOut], None]]:
     if response.status_code == 200:
         response_200 = []
         _response_200 = response.json()
@@ -65,7 +65,7 @@ def _parse_response(
 
 def _build_response(
     *, response: httpx.Response
-) -> Response[Union[List[ExtractWithConfigOut], None, None, HTTPValidationError]]:
+) -> Response[Union[HTTPValidationError, List[ExtractWithConfigOut], None]]:
     return Response(
         status_code=response.status_code,
         content=response.content,
@@ -80,7 +80,7 @@ def sync_detailed(
     name: Union[Unset, str] = "",
     limit: Union[Unset, int] = 100,
     offset: Union[Unset, int] = 0,
-) -> Response[Union[List[ExtractWithConfigOut], None, None, HTTPValidationError]]:
+) -> Response[Union[HTTPValidationError, List[ExtractWithConfigOut], None]]:
     kwargs = _get_kwargs(
         client=client,
         name=name,
@@ -101,7 +101,7 @@ def sync(
     name: Union[Unset, str] = "",
     limit: Union[Unset, int] = 100,
     offset: Union[Unset, int] = 0,
-) -> Optional[Union[List[ExtractWithConfigOut], None, None, HTTPValidationError]]:
+) -> Optional[Union[HTTPValidationError, List[ExtractWithConfigOut], None]]:
     """List the organization's extract tasks.
 
     Only orgadmins are allowed to access extract tasks.
@@ -127,7 +127,7 @@ async def asyncio_detailed(
     name: Union[Unset, str] = "",
     limit: Union[Unset, int] = 100,
     offset: Union[Unset, int] = 0,
-) -> Response[Union[List[ExtractWithConfigOut], None, None, HTTPValidationError]]:
+) -> Response[Union[HTTPValidationError, List[ExtractWithConfigOut], None]]:
     kwargs = _get_kwargs(
         client=client,
         name=name,
@@ -147,7 +147,7 @@ async def asyncio(
     name: Union[Unset, str] = "",
     limit: Union[Unset, int] = 100,
     offset: Union[Unset, int] = 0,
-) -> Optional[Union[List[ExtractWithConfigOut], None, None, HTTPValidationError]]:
+) -> Optional[Union[HTTPValidationError, List[ExtractWithConfigOut], None]]:
     """List the organization's extract tasks.
 
     Only orgadmins are allowed to access extract tasks.
