@@ -32,7 +32,7 @@ def _get_kwargs(
 
 def _parse_response(
     *, response: httpx.Response
-) -> Optional[Union[List[ExtractTopChunkOut], None, None, HTTPValidationError]]:
+) -> Optional[Union[HTTPValidationError, List[ExtractTopChunkOut], None]]:
     if response.status_code == 200:
         response_200 = []
         _response_200 = response.json()
@@ -59,7 +59,7 @@ def _parse_response(
 
 def _build_response(
     *, response: httpx.Response
-) -> Response[Union[List[ExtractTopChunkOut], None, None, HTTPValidationError]]:
+) -> Response[Union[HTTPValidationError, List[ExtractTopChunkOut], None]]:
     return Response(
         status_code=response.status_code,
         content=response.content,
@@ -72,7 +72,7 @@ def sync_detailed(
     *,
     client: AuthenticatedClient,
     json_body: SynchronousExtractCreate,
-) -> Response[Union[List[ExtractTopChunkOut], None, None, HTTPValidationError]]:
+) -> Response[Union[HTTPValidationError, List[ExtractTopChunkOut], None]]:
     kwargs = _get_kwargs(
         client=client,
         json_body=json_body,
@@ -89,7 +89,7 @@ def sync(
     *,
     client: AuthenticatedClient,
     json_body: SynchronousExtractCreate,
-) -> Optional[Union[List[ExtractTopChunkOut], None, None, HTTPValidationError]]:
+) -> Optional[Union[HTTPValidationError, List[ExtractTopChunkOut], None]]:
     """Create and run a synchronous extract task.
 
     Only orgadmins are allowed to run synchronous extract tasks.
@@ -108,7 +108,7 @@ async def asyncio_detailed(
     *,
     client: AuthenticatedClient,
     json_body: SynchronousExtractCreate,
-) -> Response[Union[List[ExtractTopChunkOut], None, None, HTTPValidationError]]:
+) -> Response[Union[HTTPValidationError, List[ExtractTopChunkOut], None]]:
     kwargs = _get_kwargs(
         client=client,
         json_body=json_body,
@@ -124,7 +124,7 @@ async def asyncio(
     *,
     client: AuthenticatedClient,
     json_body: SynchronousExtractCreate,
-) -> Optional[Union[List[ExtractTopChunkOut], None, None, HTTPValidationError]]:
+) -> Optional[Union[HTTPValidationError, List[ExtractTopChunkOut], None]]:
     """Create and run a synchronous extract task.
 
     Only orgadmins are allowed to run synchronous extract tasks.
