@@ -30,14 +30,14 @@ class ChunkOut:
     ocr: bool
     id: str
     version_id: int
-    tag_names: Union[Unset, List[List[str]]] = UNSET
+    tag_names: Union[Unset, List[Union[List[str], str]]] = UNSET
     offsets: Union[Unset, List[int]] = UNSET
     blocks: Union[Unset, List[BlockFromDigester]] = UNSET
-    coordinates: Union[ChunkOutCoordinates, Unset] = UNSET
+    coordinates: Union[Unset, ChunkOutCoordinates] = UNSET
     language: Union[Unset, str] = UNSET
     title: Union[Unset, str] = UNSET
     author: Union[Unset, str] = UNSET
-    metadata: Union[ChunkOutMetadata, Unset] = UNSET
+    metadata: Union[Unset, ChunkOutMetadata] = UNSET
     num_pages: Union[Unset, int] = UNSET
     created_on: Union[Unset, datetime.datetime] = UNSET
     updated_on: Union[Unset, datetime.datetime] = UNSET
@@ -61,19 +61,23 @@ class ChunkOut:
         ocr = self.ocr
         id = self.id
         version_id = self.version_id
-        tag_names: Union[Unset, List[Any]] = UNSET
+        tag_names: Union[Unset, List[Union[List[str], str]]] = UNSET
         if not isinstance(self.tag_names, Unset):
             tag_names = []
             for tag_names_item_data in self.tag_names:
-                tag_names_item = tag_names_item_data
+                if isinstance(tag_names_item_data, list):
+                    tag_names_item = tag_names_item_data
+
+                else:
+                    tag_names_item = tag_names_item_data
 
                 tag_names.append(tag_names_item)
 
-        offsets: Union[Unset, List[Any]] = UNSET
+        offsets: Union[Unset, List[int]] = UNSET
         if not isinstance(self.offsets, Unset):
             offsets = self.offsets
 
-        blocks: Union[Unset, List[Any]] = UNSET
+        blocks: Union[Unset, List[Dict[str, Any]]] = UNSET
         if not isinstance(self.blocks, Unset):
             blocks = []
             for blocks_item_data in self.blocks:
@@ -101,7 +105,7 @@ class ChunkOut:
         if not isinstance(self.updated_on, Unset):
             updated_on = self.updated_on.isoformat()
 
-        embedding: Union[Unset, List[Any]] = UNSET
+        embedding: Union[Unset, List[float]] = UNSET
         if not isinstance(self.embedding, Unset):
             embedding = self.embedding
 
@@ -187,7 +191,19 @@ class ChunkOut:
         tag_names = []
         _tag_names = d.pop("tag_names", UNSET)
         for tag_names_item_data in _tag_names or []:
-            tag_names_item = cast(List[str], tag_names_item_data)
+
+            def _parse_tag_names_item(data: object) -> Union[List[str], str]:
+                try:
+                    if not isinstance(data, list):
+                        raise TypeError()
+                    tag_names_item_type_1 = cast(List[str], data)
+
+                    return tag_names_item_type_1
+                except:  # noqa: E722
+                    pass
+                return cast(Union[List[str], str], data)
+
+            tag_names_item = _parse_tag_names_item(tag_names_item_data)
 
             tag_names.append(tag_names_item)
 
@@ -200,9 +216,11 @@ class ChunkOut:
 
             blocks.append(blocks_item)
 
-        coordinates: Union[ChunkOutCoordinates, Unset] = UNSET
         _coordinates = d.pop("coordinates", UNSET)
-        if not isinstance(_coordinates, Unset):
+        coordinates: Union[Unset, ChunkOutCoordinates]
+        if isinstance(_coordinates, Unset):
+            coordinates = UNSET
+        else:
             coordinates = ChunkOutCoordinates.from_dict(_coordinates)
 
         language = d.pop("language", UNSET)
@@ -211,21 +229,27 @@ class ChunkOut:
 
         author = d.pop("author", UNSET)
 
-        metadata: Union[ChunkOutMetadata, Unset] = UNSET
         _metadata = d.pop("metadata", UNSET)
-        if not isinstance(_metadata, Unset):
+        metadata: Union[Unset, ChunkOutMetadata]
+        if isinstance(_metadata, Unset):
+            metadata = UNSET
+        else:
             metadata = ChunkOutMetadata.from_dict(_metadata)
 
         num_pages = d.pop("num_pages", UNSET)
 
-        created_on: Union[Unset, datetime.datetime] = UNSET
         _created_on = d.pop("created_on", UNSET)
-        if not isinstance(_created_on, Unset):
+        created_on: Union[Unset, datetime.datetime]
+        if isinstance(_created_on, Unset):
+            created_on = UNSET
+        else:
             created_on = isoparse(_created_on)
 
-        updated_on: Union[Unset, datetime.datetime] = UNSET
         _updated_on = d.pop("updated_on", UNSET)
-        if not isinstance(_updated_on, Unset):
+        updated_on: Union[Unset, datetime.datetime]
+        if isinstance(_updated_on, Unset):
+            updated_on = UNSET
+        else:
             updated_on = isoparse(_updated_on)
 
         embedding = cast(List[float], d.pop("embedding", UNSET))
