@@ -2,6 +2,9 @@ from typing import Any, Dict, List, Type, TypeVar, Union, cast
 
 import attr
 
+from ..models.keyword_operator import KeywordOperator
+from ..models.keywords_direction import KeywordsDirection
+from ..models.keywords_scope import KeywordsScope
 from ..models.value_type import ValueType
 from ..types import UNSET, Unset
 
@@ -17,11 +20,11 @@ class ExtractValueConfig:
     all_values: bool
     keywords: List[str]
     words_around: List[str]
-    keywords_operator: Union[Unset, None] = UNSET
-    keywords_scope: Union[Unset, None] = UNSET
+    keywords_operator: Union[Unset, KeywordOperator] = KeywordOperator.AND_
+    keywords_scope: Union[Unset, KeywordsScope] = KeywordsScope.CHUNK
     start_page: Union[Unset, int] = UNSET
     end_page: Union[Unset, int] = UNSET
-    words_direction: Union[Unset, None] = UNSET
+    words_direction: Union[Unset, KeywordsDirection] = KeywordsDirection.AROUND
     words_range: Union[Unset, int] = 10
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
@@ -34,13 +37,19 @@ class ExtractValueConfig:
 
         words_around = self.words_around
 
-        keywords_operator = self.keywords_operator
+        keywords_operator: Union[Unset, str] = UNSET
+        if not isinstance(self.keywords_operator, Unset):
+            keywords_operator = self.keywords_operator.value
 
-        keywords_scope = self.keywords_scope
+        keywords_scope: Union[Unset, str] = UNSET
+        if not isinstance(self.keywords_scope, Unset):
+            keywords_scope = self.keywords_scope.value
 
         start_page = self.start_page
         end_page = self.end_page
-        words_direction = self.words_direction
+        words_direction: Union[Unset, str] = UNSET
+        if not isinstance(self.words_direction, Unset):
+            words_direction = self.words_direction.value
 
         words_range = self.words_range
 
@@ -83,15 +92,30 @@ class ExtractValueConfig:
 
         words_around = cast(List[str], d.pop("words_around"))
 
-        keywords_operator = d.pop("keywords_operator", UNSET)
+        _keywords_operator = d.pop("keywords_operator", UNSET)
+        keywords_operator: Union[Unset, KeywordOperator]
+        if isinstance(_keywords_operator, Unset):
+            keywords_operator = UNSET
+        else:
+            keywords_operator = KeywordOperator(_keywords_operator)
 
-        keywords_scope = d.pop("keywords_scope", UNSET)
+        _keywords_scope = d.pop("keywords_scope", UNSET)
+        keywords_scope: Union[Unset, KeywordsScope]
+        if isinstance(_keywords_scope, Unset):
+            keywords_scope = UNSET
+        else:
+            keywords_scope = KeywordsScope(_keywords_scope)
 
         start_page = d.pop("start_page", UNSET)
 
         end_page = d.pop("end_page", UNSET)
 
-        words_direction = d.pop("words_direction", UNSET)
+        _words_direction = d.pop("words_direction", UNSET)
+        words_direction: Union[Unset, KeywordsDirection]
+        if isinstance(_words_direction, Unset):
+            words_direction = UNSET
+        else:
+            words_direction = KeywordsDirection(_words_direction)
 
         words_range = d.pop("words_range", UNSET)
 
