@@ -2,6 +2,7 @@ from typing import Any, Dict, List, Type, TypeVar, Union, cast
 
 import attr
 
+from ..models.keyword_operator import KeywordOperator
 from ..models.search_query_keywords_filters import SearchQueryKeywordsFilters
 from ..types import UNSET, Unset
 
@@ -13,14 +14,14 @@ class SearchQueryKeywords:
     """ Schema for keyword search queries. """
 
     folder_ids: Union[Unset, List[int]] = UNSET
-    filters: Union[SearchQueryKeywordsFilters, Unset] = UNSET
+    filters: Union[Unset, SearchQueryKeywordsFilters] = UNSET
     keywords: Union[Unset, List[str]] = UNSET
-    keyword_op: Union[Unset, None] = UNSET
+    keyword_op: Union[Unset, KeywordOperator] = KeywordOperator.AND_
     file_ids: Union[Unset, List[int]] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
-        folder_ids: Union[Unset, List[Any]] = UNSET
+        folder_ids: Union[Unset, List[int]] = UNSET
         if not isinstance(self.folder_ids, Unset):
             folder_ids = self.folder_ids
 
@@ -28,15 +29,15 @@ class SearchQueryKeywords:
         if not isinstance(self.filters, Unset):
             filters = self.filters.to_dict()
 
-        keywords: Union[Unset, List[Any]] = UNSET
+        keywords: Union[Unset, List[str]] = UNSET
         if not isinstance(self.keywords, Unset):
             keywords = self.keywords
 
         keyword_op: Union[Unset, str] = UNSET
         if not isinstance(self.keyword_op, Unset):
-            keyword_op = self.keyword_op
+            keyword_op = self.keyword_op.value
 
-        file_ids: Union[Unset, List[Any]] = UNSET
+        file_ids: Union[Unset, List[int]] = UNSET
         if not isinstance(self.file_ids, Unset):
             file_ids = self.file_ids
 
@@ -61,14 +62,21 @@ class SearchQueryKeywords:
         d = src_dict.copy()
         folder_ids = cast(List[int], d.pop("folder_ids", UNSET))
 
-        filters: Union[SearchQueryKeywordsFilters, Unset] = UNSET
         _filters = d.pop("filters", UNSET)
-        if not isinstance(_filters, Unset):
+        filters: Union[Unset, SearchQueryKeywordsFilters]
+        if isinstance(_filters, Unset):
+            filters = UNSET
+        else:
             filters = SearchQueryKeywordsFilters.from_dict(_filters)
 
         keywords = cast(List[str], d.pop("keywords", UNSET))
 
-        keyword_op = d.pop("keyword_op", UNSET)
+        _keyword_op = d.pop("keyword_op", UNSET)
+        keyword_op: Union[Unset, KeywordOperator]
+        if isinstance(_keyword_op, Unset):
+            keyword_op = UNSET
+        else:
+            keyword_op = KeywordOperator(_keyword_op)
 
         file_ids = cast(List[int], d.pop("file_ids", UNSET))
 
