@@ -4,6 +4,7 @@ from typing import Any, Dict, List, Type, TypeVar, Union, cast
 import attr
 from dateutil.parser import isoparse
 
+from ..models.keyword_operator import KeywordOperator
 from ..models.search_query_out_filters import SearchQueryOutFilters
 from ..types import UNSET, Unset
 
@@ -19,9 +20,9 @@ class SearchQueryOut:
     queried_on: datetime.datetime
     id: int
     folder_ids: Union[Unset, List[int]] = UNSET
-    filters: Union[SearchQueryOutFilters, Unset] = UNSET
+    filters: Union[Unset, SearchQueryOutFilters] = UNSET
     keywords: Union[Unset, List[str]] = UNSET
-    keyword_op: Union[Unset, None] = UNSET
+    keyword_op: Union[Unset, KeywordOperator] = KeywordOperator.AND_
     keywords_only_query: Union[Unset, bool] = UNSET
     query: Union[Unset, str] = UNSET
     last_version: Union[Unset, bool] = True
@@ -34,7 +35,7 @@ class SearchQueryOut:
         queried_on = self.queried_on.isoformat()
 
         id = self.id
-        folder_ids: Union[Unset, List[Any]] = UNSET
+        folder_ids: Union[Unset, List[int]] = UNSET
         if not isinstance(self.folder_ids, Unset):
             folder_ids = self.folder_ids
 
@@ -42,18 +43,18 @@ class SearchQueryOut:
         if not isinstance(self.filters, Unset):
             filters = self.filters.to_dict()
 
-        keywords: Union[Unset, List[Any]] = UNSET
+        keywords: Union[Unset, List[str]] = UNSET
         if not isinstance(self.keywords, Unset):
             keywords = self.keywords
 
         keyword_op: Union[Unset, str] = UNSET
         if not isinstance(self.keyword_op, Unset):
-            keyword_op = self.keyword_op
+            keyword_op = self.keyword_op.value
 
         keywords_only_query = self.keywords_only_query
         query = self.query
         last_version = self.last_version
-        version_ids: Union[Unset, List[Any]] = UNSET
+        version_ids: Union[Unset, List[int]] = UNSET
         if not isinstance(self.version_ids, Unset):
             version_ids = self.version_ids
 
@@ -99,14 +100,21 @@ class SearchQueryOut:
 
         folder_ids = cast(List[int], d.pop("folder_ids", UNSET))
 
-        filters: Union[SearchQueryOutFilters, Unset] = UNSET
         _filters = d.pop("filters", UNSET)
-        if not isinstance(_filters, Unset):
+        filters: Union[Unset, SearchQueryOutFilters]
+        if isinstance(_filters, Unset):
+            filters = UNSET
+        else:
             filters = SearchQueryOutFilters.from_dict(_filters)
 
         keywords = cast(List[str], d.pop("keywords", UNSET))
 
-        keyword_op = d.pop("keyword_op", UNSET)
+        _keyword_op = d.pop("keyword_op", UNSET)
+        keyword_op: Union[Unset, KeywordOperator]
+        if isinstance(_keyword_op, Unset):
+            keyword_op = UNSET
+        else:
+            keyword_op = KeywordOperator(_keyword_op)
 
         keywords_only_query = d.pop("keywords_only_query", UNSET)
 
