@@ -16,7 +16,7 @@ class SearchResultChunks:
     query_id: int
     chunks: List[ChunkResult]
     stripped_query: List[str]
-    pipeline_logs: Union[SearchResultPipelineLogs, Unset] = UNSET
+    pipeline_logs: Union[Unset, SearchResultPipelineLogs] = UNSET
     suggested_query: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
@@ -66,9 +66,11 @@ class SearchResultChunks:
 
         stripped_query = cast(List[str], d.pop("stripped_query"))
 
-        pipeline_logs: Union[SearchResultPipelineLogs, Unset] = UNSET
         _pipeline_logs = d.pop("pipeline_logs", UNSET)
-        if not isinstance(_pipeline_logs, Unset):
+        pipeline_logs: Union[Unset, SearchResultPipelineLogs]
+        if isinstance(_pipeline_logs, Unset):
+            pipeline_logs = UNSET
+        else:
             pipeline_logs = SearchResultPipelineLogs.from_dict(_pipeline_logs)
 
         suggested_query = d.pop("suggested_query", UNSET)
