@@ -15,13 +15,13 @@ class SynchronousExtractCreate:
     """ Schema for simple extract task generation """
 
     file_id: int
-    config: Union[Unset, ExtractValueConfig, ExtractParagraphConfig, ExtractQuestionConfig] = UNSET
+    config: Union[ExtractParagraphConfig, ExtractQuestionConfig, ExtractValueConfig, Unset] = UNSET
     model_id: Union[Unset, int] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         file_id = self.file_id
-        config: Union[Unset, ExtractValueConfig, ExtractParagraphConfig, ExtractQuestionConfig]
+        config: Union[Dict[str, Any], Unset]
         if isinstance(self.config, Unset):
             config = UNSET
         elif isinstance(self.config, ExtractValueConfig):
@@ -60,33 +60,47 @@ class SynchronousExtractCreate:
         d = src_dict.copy()
         file_id = d.pop("file_id")
 
-        def _parse_config(data: Any) -> Union[Unset, ExtractValueConfig, ExtractParagraphConfig, ExtractQuestionConfig]:
-            data = None if isinstance(data, Unset) else data
-            config: Union[Unset, ExtractValueConfig, ExtractParagraphConfig, ExtractQuestionConfig]
+        def _parse_config(
+            data: object,
+        ) -> Union[ExtractParagraphConfig, ExtractQuestionConfig, ExtractValueConfig, Unset]:
+            if isinstance(data, Unset):
+                return data
             try:
-                config = UNSET
-                _config = data
-                if not isinstance(_config, Unset):
-                    config = ExtractValueConfig.from_dict(_config)
+                if not isinstance(data, dict):
+                    raise TypeError()
+                _config_type_0 = data
+                config_type_0: Union[Unset, ExtractValueConfig]
+                if isinstance(_config_type_0, Unset):
+                    config_type_0 = UNSET
+                else:
+                    config_type_0 = ExtractValueConfig.from_dict(_config_type_0)
 
-                return config
+                return config_type_0
             except:  # noqa: E722
                 pass
             try:
-                config = UNSET
-                _config = data
-                if not isinstance(_config, Unset):
-                    config = ExtractParagraphConfig.from_dict(_config)
+                if not isinstance(data, dict):
+                    raise TypeError()
+                _config_type_1 = data
+                config_type_1: Union[Unset, ExtractParagraphConfig]
+                if isinstance(_config_type_1, Unset):
+                    config_type_1 = UNSET
+                else:
+                    config_type_1 = ExtractParagraphConfig.from_dict(_config_type_1)
 
-                return config
+                return config_type_1
             except:  # noqa: E722
                 pass
-            config = UNSET
-            _config = data
-            if not isinstance(_config, Unset):
-                config = ExtractQuestionConfig.from_dict(_config)
+            if not isinstance(data, dict):
+                raise TypeError()
+            _config_type_2 = data
+            config_type_2: Union[Unset, ExtractQuestionConfig]
+            if isinstance(_config_type_2, Unset):
+                config_type_2 = UNSET
+            else:
+                config_type_2 = ExtractQuestionConfig.from_dict(_config_type_2)
 
-            return config
+            return config_type_2
 
         config = _parse_config(d.pop("config", UNSET))
 
