@@ -375,7 +375,7 @@ class Timezone(str, Enum):
     BRAZILEAST = "Brazil/East"
     BRAZILWEST = "Brazil/West"
     CET = "CET"
-    C_S_T6_CDT = "CST6CDT"
+    CST6CDT = "CST6CDT"
     CANADAATLANTIC = "Canada/Atlantic"
     CANADACENTRAL = "Canada/Central"
     CANADAEASTERN = "Canada/Eastern"
@@ -389,10 +389,10 @@ class Timezone(str, Enum):
     CUBA = "Cuba"
     EET = "EET"
     EST = "EST"
-    E_S_T5_EDT = "EST5EDT"
+    EST5EDT = "EST5EDT"
     EGYPT = "Egypt"
     EIRE = "Eire"
-    E_T_C_G_M_T0 = "Etc/GMT0"
+    ETCGMT0 = "Etc/GMT0"
     ETCGREENWICH = "Etc/Greenwich"
     ETCUCT = "Etc/UCT"
     ETCUTC = "Etc/UTC"
@@ -463,7 +463,7 @@ class Timezone(str, Enum):
     EUROPEZURICH = "Europe/Zurich"
     GB = "GB"
     GB_EIRE = "GB-Eire"
-    G_M_T0 = "GMT0"
+    GMT0 = "GMT0"
     GREENWICH = "Greenwich"
     HST = "HST"
     HONGKONG = "Hongkong"
@@ -487,7 +487,7 @@ class Timezone(str, Enum):
     LIBYA = "Libya"
     MET = "MET"
     MST = "MST"
-    M_S_T7_MDT = "MST7MDT"
+    MST7MDT = "MST7MDT"
     MEXICOBAJANORTE = "Mexico/BajaNorte"
     MEXICOBAJASUR = "Mexico/BajaSur"
     MEXICOGENERAL = "Mexico/General"
@@ -495,7 +495,7 @@ class Timezone(str, Enum):
     NZ_CHAT = "NZ-CHAT"
     NAVAJO = "Navajo"
     PRC = "PRC"
-    P_S_T8_PDT = "PST8PDT"
+    PST8PDT = "PST8PDT"
     PACIFICAPIA = "Pacific/Apia"
     PACIFICAUCKLAND = "Pacific/Auckland"
     PACIFICBOUGAINVILLE = "Pacific/Bougainville"
