@@ -28,7 +28,7 @@ class Version:
     author: Union[Unset, str] = UNSET
     language: Union[Unset, str] = UNSET
     num_pages: Union[Unset, int] = UNSET
-    metadata: Union[VersionMetadata, Unset] = UNSET
+    metadata: Union[Unset, VersionMetadata] = UNSET
     chunked: Union[Unset, bool] = False
     chunk_timestamp: Union[Unset, datetime.datetime] = UNSET
     ocr: Union[Unset, bool] = False
@@ -101,7 +101,7 @@ class Version:
             field_dict["metadata"] = metadata
         if chunked is not UNSET:
             field_dict["chunked"] = chunked
-        if chunk_timestamp is not None and chunk_timestamp is not UNSET:
+        if chunk_timestamp is not UNSET:
             field_dict["chunk_timestamp"] = chunk_timestamp
         if ocr is not UNSET:
             field_dict["ocr"] = ocr
@@ -145,28 +145,36 @@ class Version:
 
         num_pages = d.pop("num_pages", UNSET)
 
-        metadata: Union[VersionMetadata, Unset] = UNSET
         _metadata = d.pop("metadata", UNSET)
-        if not isinstance(_metadata, Unset):
+        metadata: Union[Unset, VersionMetadata]
+        if isinstance(_metadata, Unset):
+            metadata = UNSET
+        else:
             metadata = VersionMetadata.from_dict(_metadata)
 
         chunked = d.pop("chunked", UNSET)
 
-        chunk_timestamp: Union[Unset, datetime.datetime] = UNSET
         _chunk_timestamp = d.pop("chunk_timestamp", UNSET)
-        if _chunk_timestamp and not isinstance(_chunk_timestamp, Unset):
+        chunk_timestamp: Union[Unset, datetime.datetime]
+        if isinstance(_chunk_timestamp, Unset):
+            chunk_timestamp = UNSET
+        else:
             chunk_timestamp = isoparse(_chunk_timestamp)
 
         ocr = d.pop("ocr", UNSET)
 
-        created_on: Union[Unset, datetime.datetime] = UNSET
         _created_on = d.pop("created_on", UNSET)
-        if not isinstance(_created_on, Unset):
+        created_on: Union[Unset, datetime.datetime]
+        if isinstance(_created_on, Unset):
+            created_on = UNSET
+        else:
             created_on = isoparse(_created_on)
 
-        updated_on: Union[Unset, datetime.datetime] = UNSET
         _updated_on = d.pop("updated_on", UNSET)
-        if not isinstance(_updated_on, Unset):
+        updated_on: Union[Unset, datetime.datetime]
+        if isinstance(_updated_on, Unset):
+            updated_on = UNSET
+        else:
             updated_on = isoparse(_updated_on)
 
         idx_task_id = d.pop("idx_task_id", UNSET)
